@@ -12,13 +12,15 @@ from inspect import isawaitable
 from typing import TYPE_CHECKING
 
 import structlog
+from starlite.constants import SCOPE_STATE_RESPONSE_COMPRESSED
 from starlite.enums import ScopeType
 from starlite.utils.extractors import ConnectionDataExtractor, ResponseDataExtractor
+from starlite.utils.scope import get_starlite_scope_state
 
 from starlite_saqlalchemy import settings
 
 if TYPE_CHECKING:
-    from typing import Any
+    from typing import Any, Literal
 
     from starlite.connection import Request
     from starlite.datastructures import State
@@ -27,6 +29,9 @@ if TYPE_CHECKING:
 
 LOGGER = structlog.get_logger()
 
+HTTP_RESPONSE_START: Literal["http.response.start"] = "http.response.start"
+HTTP_RESPONSE_BODY: Literal["http.response.body"] = "http.response.body"
+
 
 def drop_health_logs(_: WrappedLogger, __: str, event_dict: EventDict) -> EventDict:
     """Prevent logging of successful health checks.
@@ -58,7 +63,7 @@ def middleware_factory(app: ASGIApp) -> ASGIApp:
     """
 
     async def middleware(scope: Scope, receive: Receive, send: Send) -> None:
-        """Cleans up the structlog contextvars.
+        """Clean up structlog contextvars.
 
         Args:
             scope: ASGI connection scope.
@@ -78,15 +83,18 @@ class BeforeSendHandler:
         "do_log_request",
         "do_log_response",
         "exclude_paths",
+        "include_compressed_body",
         "logger",
         "request_extractor",
         "response_extractor",
     )
 
     def __init__(self) -> None:
+        """Configure the handler."""
         self.exclude_paths = re.compile(settings.log.EXCLUDE_PATHS)
         self.do_log_request = bool(settings.log.REQUEST_FIELDS)
         self.do_log_response = bool(settings.log.RESPONSE_FIELDS)
+        self.include_compressed_body = settings.log.INCLUDE_COMPRESSED_BODY
         self.request_extractor = ConnectionDataExtractor(
             extract_body="body" in settings.log.REQUEST_FIELDS,
             extract_client="client" in settings.log.REQUEST_FIELDS,
@@ -122,14 +130,14 @@ class BeforeSendHandler:
         if scope["type"] == ScopeType.HTTP and self.exclude_paths.findall(scope["path"]):
             return
 
-        if message["type"] == "http.response.start":
+        if message["type"] == HTTP_RESPONSE_START:
             scope["state"]["log_level"] = (
                 logging.ERROR if message["status"] >= 500 else logging.INFO
             )
-            scope["state"]["http.response.start"] = message
+            scope["state"][HTTP_RESPONSE_START] = message
         # ignore intermediate content of streaming responses for now.
-        elif message["type"] == "http.response.body" and message["more_body"] is False:
-            scope["state"]["http.response.body"] = message
+        elif message["type"] == HTTP_RESPONSE_BODY and message["more_body"] is False:
+            scope["state"][HTTP_RESPONSE_BODY] = message
             if self.do_log_request:
                 await self.log_request(scope)
             if self.do_log_response:
@@ -137,10 +145,11 @@ class BeforeSendHandler:
             await LOGGER.alog(scope["state"]["log_level"], settings.log.HTTP_EVENT)
 
     async def log_request(self, scope: "Scope") -> None:
-        """Handles extracting the request data and logging the message.
+        """Handle extracting the request data and logging the message.
 
         Args:
             scope: The ASGI connection scope.
+
         Returns:
             None
         """
@@ -148,10 +157,11 @@ class BeforeSendHandler:
         structlog.contextvars.bind_contextvars(request=extracted_data)
 
     async def log_response(self, scope: "Scope") -> None:
-        """Handles extracting the response data and logging the message.
+        """Handle extracting the response data and logging the message.
 
         Args:
             scope: The ASGI connection scope.
+
         Returns:
             None
         """
@@ -159,10 +169,11 @@ class BeforeSendHandler:
         structlog.contextvars.bind_contextvars(response=extracted_data)
 
     async def extract_request_data(self, request: Request) -> dict[str, Any]:
-        """Creates a dictionary of values for the log.
+        """Create a dictionary of values for the log.
 
         Args:
             request: A [Request][starlite.connection.request.Request] instance.
+
         Returns:
             An OrderedDict.
         """
@@ -179,24 +190,24 @@ class BeforeSendHandler:
         return data
 
     def extract_response_data(self, scope: Scope) -> dict[str, Any]:
-        """Extracts data from the response.
+        """Extract data from the response.
 
         Args:
             scope: The ASGI connection scope.
+
         Returns:
             An OrderedDict.
         """
         data: dict[str, Any] = {}
         extracted_data = self.response_extractor(
-            messages=(
-                scope["state"]["http.response.start"],
-                scope["state"]["http.response.body"],
-            )
+            messages=(scope["state"][HTTP_RESPONSE_START], scope["state"][HTTP_RESPONSE_BODY])
         )
         missing = object()
+        response_body_compressed = get_starlite_scope_state(scope, SCOPE_STATE_RESPONSE_COMPRESSED)
         for key in settings.log.RESPONSE_FIELDS:
-            # https://github.com/starlite-api/starlite/issues/740
             value = extracted_data.get(key, missing)
+            if key == "body" and response_body_compressed and not self.include_compressed_body:
+                continue
             if value is missing:  # pragma: no cover
                 continue
             data[key] = value
